# **imgbase64**
![enter image description here](https://img.shields.io/pypi/v/imgbase64.svg?color=gree)

transform images into base64

**Command line usage**

    python3 -m imgbase64 --url <url to image>
    python3 -m imgbase64 --file <path to file>
**Import usage**

    import imagbase64
    imgbase64.url2base64(<url to image>)
    imgbase64.file2base64(<path to file>)

